@@ -61,8 +61,8 @@
 #' no3 <- normalizeThis(dat1, refGrp=1:3, meth="median")
 #' no4 <- normalizeThis(dat1, refGrp=1:3, meth="slope", quantFa=c(0.2,0.8))
 #' dat1[c(1:10,91:100),]
-#' cor(dat1[,3],rowMeans(dat1[,1:2],na.rm=TRUE),use="complete.obs")             # high
-#' cor(dat1[,4],rowMeans(dat1[,1:2],na.rm=TRUE),use="complete.obs")             # bad
+#' cor(dat1[,3],rowMeans(dat1[,1:2],na.rm=TRUE), use="complete.obs")             # high
+#' cor(dat1[,4],rowMeans(dat1[,1:2],na.rm=TRUE), use="complete.obs")             # bad
 #' cor(dat1[c(1:10,91:100),4],rowMeans(dat1[c(1:10,91:100),1:2],na.rm=TRUE),use="complete.obs")
 #' cor(dat1[,3],rowMeans(dat1[,1:2],na.rm=TRUE)^ (1/seq(2,5,length.out=100)),use="complete.obs")
 #' @export
@@ -78,7 +78,7 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
   method <- if(any(chMe)) naOmit(method)[1] else method[1]
   if(length(dim(dat)) !=2) stop(" expecting matrix or data.frame with >= 2 rows as 'dat' !")
   if(!is.matrix(dat)) dat <- as.matrix(dat)
-  if(!is.null(refLines)) if(identical(refLines,1:nrow(dat))) {refLines <- NULL; if(!silent) message(fxNa," omit redundant 'refLines'")}
+  if(!is.null(refLines)) if(identical(refLines, 1:nrow(dat))) {refLines <- NULL; if(!silent) message(fxNa," omit redundant 'refLines'")}
   ## assemble parameters
   params <- list(refLines=refLines, trimFa=trimFa, useQ=quantFa, useExp=expFa)
   
@@ -125,6 +125,24 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
   if(inherits(out, "try-error")) { message(fxNa," Could not run normalization by '",method,"' which gave an error (returning unnormalized)"); out <- dat}
   out }
 
+#' Main Normalization function
+#'
+#' This function aims to normalize a matrix or data.frame by columns. 
+#' It assumes all checks have been done before calling this function.
+#' 
+#' @param dat matrix or data.frame of data to get normalized
+#' @param meth (character) may be "mean","median","NULL","none", "trimMean", "rowNormalize", "slope", "exponent", "slope2Sections", "vsn"; When \code{NULL} or 'none' is chosen the input will be returned
+#' @param mode (character) may be "proportional", "additive";
+#'  decide if normalizatio factors will be applies as multiplicative (proportional) or additive; for log2-omics data \code{mode="aditive"} is suggested
+#' @param param (list) additional parameters
+#' @param silent (logical) suppress messages
+#' @param debug (logical) additional messages for debugging
+#' @param callFrom (character) allows easier tracking of messages produced
+#' @return This function returns a numeric vector
+#' @seealso \code{\link{normalizeThis}}
+#' @examples
+#' aa <- matrix(1:12, ncol=3)
+#' .normalize(aa,"median",mode="proportional",param=NULL)
 #' @export
 .normalize <- function(dat, meth, mode, param, silent=FALSE, debug=FALSE, callFrom=NULL){
   ## 'dat' .. matrix (>1 col, >1 li) to be normalized
@@ -133,12 +151,12 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
   fxNa <- ".normalize"
   mode <- if(identical(mode,"additive")) "Add" else "Prop"       # reduce to short name
   if(identical(meth,"average")) meth <- "mean"
-  asRefL <- (length(param$refLines) < nrow(dat) & !is.null(param$refLines))
+  asRefL <- (length(param$refLines) < nrow(dat) && !is.null(param$refLines))
   datRef <- if(asRefL) {if(length(param$refLines) >1) dat[param$refLines,] else matrix(dat[param$refLines,],nrow=1)} else NULL
   if("vsn" %in% meth) {
     chPa <- requireNamespace("vsn", quietly=TRUE)
     if(!chPa) { meth <- "mean"
-      warning(fxNa, "package 'vsn' not found ! Please install first from Bioconductor; resetting to default 'mean'")
+      warning(fxNa, "Package 'vsn' not found ! Please install first from Bioconductor; resetting to default 'mean'")
     }
     if(nrow(if(asRefL) datRef else dat) <42) message(callFrom," PROBLEM : Too few lines of data to run 'vsn' ! ")}
   ## Some methods have not yet been adopted/declined to additive/proportional mode
@@ -167,8 +185,25 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
     vsn=try(vsn::justvsn(dat), silent=TRUE) )
   }
 
-#' @export
-.normConstSlope <- function(mat, useQuant=c(0.2,0.8), refLines=NULL, diagPlot=TRUE, plotLog="", datName=NULL, silent=FALSE, callFrom=NULL){
+#' Normalize columns of 2dim matrix to common linear regression fit
+#'
+#' This function aims to normalize columns of 2dim matrix to common linear regression fit within range of 'useQuant'
+#' 
+#' @param mat matrix or data.frame of data to get normalized
+#' @param useQuant (numeric) quantiles to use
+#' @param refLines (NULL or numeric) allows to consider only specific lines of 'dat' when determining normalization factors (all data will be normalized)
+#' @param diagPlot (logical) draw diagnistic plot
+#' @param plotLog (character) indicate which axis shousl be diplayed on log-scale, may be 'x', 'xy' or 'y'
+#' @param datName  (character) use as title in diag plot
+#' @param silent (logical) suppress messages
+#' @param debug (logical) additional messages for debugging
+#' @param callFrom (character) allows easier tracking of messages produced
+#' @return This function returns a numeric vector
+#' @examples
+#' aa <- matrix(1:12, ncol=3)
+#' @seealso \code{\link{normalizeThis}}
+##' @export
+.normConstSlope <- function(mat, useQuant=c(0.2,0.8), refLines=NULL, diagPlot=TRUE, plotLog="", datName=NULL, silent=FALSE, debug=FALSE, callFrom=NULL){
   ## normalize columns of 2dim matrix to common linear regression fit within range of 'useQuant'
   ## returns normalized data (2dim matrix)
   ## in case of matrixes, data will be normalized by columns, but only the average of all indiv regression-lines will be shown on graph
@@ -180,16 +215,16 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
   msg1 <- " 'useQuant' should be vector of two numeric values between 0 & 1"
   msg2 <- paste(" 'mat' should be matrix with two dimensions. Here it appears as ")
   if(!is.numeric(mat)) stop(fxNa,msg2,class(mat)," with ",mode(mat)," data of ",length(dim(mat))," dims")
-  if(sum(is.finite(useQuant)) != 2 | length(useQuant) !=2) {message(fxNa,msg1); useQuant=c(0.2,0.8)}
-  if(useQuant[1] < 0 | useQuant[1] > 1) {message(msg1); useQuant=c(0.2,0.8)}
+  if(sum(is.finite(useQuant)) != 2 || length(useQuant) !=2) {message(fxNa,msg1); useQuant=c(0.2,0.8)}
+  if(useQuant[1] < 0 || useQuant[1] > 1) {message(msg1); useQuant=c(0.2,0.8)}
   if(plotLog %in% c("x","xy")) {matOri <- mat; mat <- log(mat); message(fxNa," ..setting data to log")}
-  quantVal <- apply(mat,2,stats::quantile,useQuant,na.rm=TRUE)
+  quantVal <- apply(mat, 2, stats::quantile, useQuant,na.rm=TRUE)
   tmp <- apply(mat, 2, function(x) {x <- naOmit(x); x[x >= stats::quantile(x,min(useQuant),na.rm=TRUE) & x <= stats::quantile(x,max(useQuant),na.rm=TRUE)]})
   if(!is.list(tmp)) tmp <- as.data.frame(tmp)
-  regr <- sapply(if(length(refLines) < nrow(mat) & !is.null(refLines)) tmp[refLines,] else tmp,.datSlope,toNinX=TRUE)
-  regr[1,] <- regr[1,] + apply(rbind(quantVal[1,],mat),2,function(x) sum(x[-1] < x[1],na.rm=TRUE))    # correct intercept for no of quantile-omitted data
+  regr <- sapply(if(length(refLines) < nrow(mat) && !is.null(refLines)) tmp[refLines,] else tmp,.datSlope,toNinX=TRUE)
+  regr[1,] <- regr[1,] + apply(rbind(quantVal[1,],mat), 2, function(x) sum(x[-1] < x[1], na.rm=TRUE))    # correct intercept for no of quantile-omitted data
   regrM <- rowMeans(regr, na.rm=FALSE)
-  normD <- apply(rbind(regr, mat),2,function(x) (x[-1*(1:2)]-(regrM[1]-x[1])/x[2]) *x[2]/regrM[2])
+  normD <- apply(rbind(regr, mat), 2, function(x) (x[-1*(1:2)] -(regrM[1]-x[1])/x[2]) *x[2]/regrM[2])
   if(plotLog %in% c("x","xy")) normD <- exp(normD)
   if(diagPlot) {
     msg2 <- paste(fxNa," Unknow argument content ('",plotLog,"') for 'plotLog'; resetting to default no log",sep="")
@@ -198,16 +233,18 @@ normalizeThis <- function(dat, method="mean", refLines=NULL, refGrp=NULL, mode="
     yLab <- "number of values"
     xLab <- "sorted values"
     xDat <- sort(normD[which(is.finite(normD[,1])),1])
-    if(length(refLines) < nrow(mat) & !is.null(refLines)) { graphics::plot(1:sum(is.finite(normD[refLines,1])) ~ sort(normD[which(is.finite(normD[refLines,1])),1]),
-      type="s",main=paste("normalizing ",datName),log=plotLog,col=3,xlab=xLab,ylab=yLab)
-      graphics::points(sort(normD[which(is.finite(normD[-1*refLines,1])),1]),1:sum(is.finite(normD[-1*refLines,1])),type="s",col=grDevices::grey(0.4))
-    } else graphics::plot(1:sum(is.finite(normD[,1])) ~ sort(normD[which(is.finite(normD[,1])),1]),type="s",main=paste("normalizing ",datName),log=plotLog,col=3,xlab=xLab,ylab=yLab)
-    for(ii in 2:ncol(normD)) if(length(refLines) < nrow(mat) & !is.null(refLines)) {
-      graphics::points(1:sum(is.finite(normD[refLines,ii]))~ sort(normD[which(is.finite(normD[refLines,ii])),ii]),type="s",col=ii+2)
-      graphics::points(sort(normD[which(is.finite(normD[-1*refLines,ii])),1]),1:sum(is.finite(normD[-1*refLines,ii])),type="s",col=grDevices::grey(0.4))
-    } else graphics::points(1:sum(is.finite(normD[,ii]))~ sort(normD[which(is.finite(normD[,ii])),ii]),type="s",col=ii+2)
-    graphics::abline(h=useQuant*sum(!is.na(normD))/ncol(normD),lty=3,col=grDevices::grey(0.6))
-    if(plotLog %in% c("x","xy")) graphics::curve(log(regrM[1])*(regrM[2])+regrM[1],lty=2,col=2,add=TRUE) else graphics::abline(regrM[1],regrM[2],lty=2,col=2)
-    }
+    if(length(refLines) < nrow(mat) && !is.null(refLines)) { chG <- try(graphics::plot(1:sum(is.finite(normD[refLines,1])) ~ sort(normD[which(is.finite(normD[refLines,1])),1]),
+      type="s", main=paste("normalizing ",datName),log=plotLog,col=3,xlab=xLab,ylab=yLab), silent=TRUE)
+      if(inherits(chG, "try-error")) message(fxNa,"UNABLE to draw figure !") else { 
+        graphics::points(sort(normD[which(is.finite(normD[-1*refLines,1])),1]), 1:sum(is.finite(normD[-1*refLines,1])), type="s",col=grDevices::grey(0.4))}
+    } else chG <- try(graphics::plot(1:sum(is.finite(normD[,1])) ~ sort(normD[which(is.finite(normD[,1])),1]), type="s",main=paste("normalizing ",datName), log=plotLog,col=3,xlab=xLab,ylab=yLab), silent=TRUE)
+    if(inherits(chG, "try-error")) message(fxNa,"UNABLE to draw figure !") else {    
+      for(ii in 2:ncol(normD)) if(length(refLines) < nrow(mat) && !is.null(refLines)) {
+        graphics::points(1:sum(is.finite(normD[refLines,ii]))~ sort(normD[which(is.finite(normD[refLines,ii])),ii]),type="s",col=ii+2)
+        graphics::points(sort(normD[which(is.finite(normD[-1*refLines,ii])),1]), 1:sum(is.finite(normD[-1*refLines,ii])),type="s",col=grDevices::grey(0.4))
+      } else graphics::points(1:sum(is.finite(normD[,ii]))~ sort(normD[which(is.finite(normD[,ii])),ii]), type="s",col=ii+2)
+      graphics::abline(h=useQuant*sum(!is.na(normD))/ncol(normD), lty=3,col=grDevices::grey(0.6))
+      if(plotLog %in% c("x","xy")) graphics::curve(log(regrM[1])*(regrM[2]) +regrM[1], lty=2,col=2,add=TRUE) else graphics::abline(regrM[1],regrM[2],lty=2,col=2)
+    } }
   normD }
 
