@@ -209,7 +209,7 @@ arrayCV(arr1, byDim=2)
 cutArrayInCluLike(arr1, cluOrg=c(2,1,2,1))
 
 ## ----filt3dimArr, echo=TRUE---------------------------------------------------
-filt3dimArr(arr1,displCrit=c("col1","col2"), filtCrit="col2", filtVal=7, filtTy=">")
+filt3dimArr(arr1, displCrit=c("col1","col2"), filtCrit="col2", filtVal=7, filtTy=">")
 
 ## ----repeated1, echo=TRUE-----------------------------------------------------
 ## some text toy data
@@ -451,9 +451,9 @@ replicateStructure(bb, method="combAll")
 replicateStructure(bb, method="combNonOrth")
 
 ## ----checkSimValueInSer, echo=TRUE--------------------------------------------
-va1 <- c(4:7,7,7,7,7,8:10) +(1:11)/28600
-checkSimValueInSer(va1)
-cbind(va=va1, simil=checkSimValueInSer(va1))
+va1 <- c(4:7,7,7,7,7,8:10) + (1:11)/28600
+checkSimValueInSer(va1, ppm=5)
+data.frame(va=sort(va1), simil=checkSimValueInSer(va1))
 
 ## ----findCloseMatch1, echo=TRUE-----------------------------------------------
 aA <- c(11:17); bB <- c(12.001,13.999); cC <- c(16.2,8,9,12.5,15.9,13.5,15.7,14.1,5)
@@ -538,11 +538,54 @@ keepCommonText(txt1, side="center")       # computationally easier
 txt2 <- c("abcd_abc_kjh", "bcd_abc123", "cd_abc_po")
 keepCommonText(txt2, side="center")       
 
+## ----rmEnumeratorName1, echo=TRUE---------------------------------------------
+xx <- c("hg_Re1","hjRe2_Re2","hk-Re3_Re33")
+rmEnumeratorName(xx)
+rmEnumeratorName(xx, newSep="--")
+rmEnumeratorName(xx, incl="anyCase")
+
+## ----rmEnumeratorName2, echo=TRUE---------------------------------------------
+xy <- cbind(a=11:13, b=c("11#11","2_No2","333_samp333"), c=xx)
+rmEnumeratorName(xy)
+rmEnumeratorName(xy,incl=c("anyCase","trim2","rmEnumL"))
+
+## ----rmEnumeratorName3, echo=TRUE---------------------------------------------
+xz <- cbind(a=11:13, b=c("23#11","4#2","567#333"), c=xx)
+apply(xz, 2, rmEnumeratorName, sepEnum=c("","_"), newSep="_", silent=TRUE)
+
 ## ----unifyEnumerator1, echo=TRUE----------------------------------------------
 unifyEnumerator(c("ab-1","ab-2","c-3"))
 unifyEnumerator(c("ab-R1","ab-R2","c-R3"))
 unifyEnumerator(c("ab-1","c3-2","dR3"), stringentMatch=FALSE)
 
+## ----adjustUnitPrefix1, echo=TRUE---------------------------------------------
+adjustUnitPrefix(c("10.psec","2 fsec"), unit="sec")
+
+## ----adjustUnitPrefix2, echo=TRUE---------------------------------------------
+adjustUnitPrefix(c("10.psec abc","2 fsec etc"), unit="sec")
+
+## ----mergeVectors1, echo=TRUE-------------------------------------------------
+x1 <- c(a=1, b=11, c=21)
+x2 <- c(b=12, c=22, a=2)
+x3 <- c(a=3, d=43)
+mergeVectors(vect1=x1, vect2=x2, vect3=x3)
+
+## ----mergeVectors2, echo=TRUE-------------------------------------------------
+mergeVectors(vect1=x1, vect2=x2, vect3=x3, inclInfo=TRUE)   # return list with additional info
+
+## ----mergeVectors3, echo=TRUE-------------------------------------------------
+x4 <- 41:44            # no names - not conform for merging and will be ignored
+mergeVectors(x1, x2, x3, x4)
+
+## ----matchMatrixLinesToRef1, echo=TRUE----------------------------------------
+## Note : columns b and e allow non-ambigous match, not all elements of e are present in a
+mat0 <- cbind(a=c("mvvk","axxd","bxxd","vv"),b=c("iwwy","iyyu","kvvh","gxx"), c=rep(9,4),
+  d=c("hgf","hgf","vxc","nvnn"), e=c("_vv_","_ww_","_xx_","_yy_"))
+matchMatrixLinesToRef(mat0[,1:4], ref=mat0[,5])
+matchMatrixLinesToRef(mat0[,1:4], ref=mat0[1:3,5], inclInfo=TRUE)
+
+matchMatrixLinesToRef(mat0[,-2], ref=mat0[,2], inclInfo=TRUE)   # needs 'reverse grep'
+
 ## ----orderMatrToRef1, echo=TRUE-----------------------------------------------
 mat1 <- matrix(paste0("__",letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], rep(1:5)), ncol=3)
 orderMatrToRef(mat1, paste0(letters[c(3,4,5,3,4)],c(1,3,5,2,4)))
@@ -553,6 +596,23 @@ orderMatrToRef(mat2, paste0(letters[c(3,4,5,3,4)],c(1,3,5,1,4)))
 mat3 <- matrix(paste0(letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], c(rep(1:5,2),1,1,3,3,5 )), ncol=3)
 orderMatrToRef(mat3, paste0("__",letters[c(3,4,5,3,4)],c(1,3,5,1,3)))
 
+## ----concatMatch1, echo=TRUE--------------------------------------------------
+## simple example without concatenations or text-extensions
+x0 <- c("ZZ","YY","AA","BB","DD","CC","D")
+tab0 <- c("AA","BB,E","CC","FF,U")
+match(x0, tab0)
+concatMatch(x0, tab0)         # same result as match(), but with names
+
+## now let's construct somthing similar but with concatenations and text-extensions
+x1 <- c("ZZ","YY","AA","BB-2","DD","CCdef","Dxy")            # modif of single ID (no concat)
+tab1 <- c("AA","WW,Vde,BB-5,E","CCab","FF,Uef")
+match(x1, tab1)                   # match finds only the 'simplest' case (ie "AA")
+concatMatch(x1, tab1)             # finds all hits as in example above
+
+x2 <- c("ZZ,Z","YY,Y","AA,Z,Y","BB-2","DD","X,CCdef","Dxy")  # conatenated in 'x'
+tab2 <- c("AA","WW,Vde,BB-5,E","CCab,WW","FF,UU")
+concatMatch(x2, tab2)               # concatenation in both 'x' and 'table'
+
 ## ----checkStrictOrder1, echo=TRUE---------------------------------------------
 set.seed(2005); mat1 <- rbind(matrix(round(runif(40),1),nc=4), rep(1,4))
 head(mat1)
